\name{MultiModGraph}
\alias{MultiModGraph}
\title{Multi-Predictor Moderator Graph
}
\description{Outputs a scatterplot and boxplot faceted by the categorical moderator from a fixed or random effects moderator analysis. Used to visually depict multi-predictor moderators.
}
\usage{
MultiModGraph(meta, conmod, catmod, method = "random", conmod.name = NULL, title = NULL)
}
\arguments{
  \item{meta}{data.frame with r (correlation coefficients) and n (sample size) for each study.
}
  \item{conmod}{Continuous moderator variable used for analysis.
}
  \item{catmod}{Categorical moderator variable used for analysis.  
}
  \item{method}{Model used, either \code{"random"} or \code{"fixed"} effects. Default is \code{"random"}.
}
  \item{conmod.name}{Name of continuous moderator variable to appear on x-axis of plot. Default is NULL.
}
  \item{title}{Plot title. Default is NULL.
}
}
\value{Multivariate moderator scatterplot graph faceted by levels of categorical moderator. Also, places a weighted regression line based on either a fixed or random effects analysis. The ggplot2 packages outputs the rich graphics.  
}
\references{ Cooper, H., Hedges, L.V., & Valentine, J.C. (2009). The handbook of research synthesis and meta-analysis (2nd edition). New York: Russell Sage Foundation. 
}
\author{ AC Del Re & William T. Hoyt 
}
\examples{
# Data Set III (Cooper et al., 2009; pp. 265 & 587)

id<-rep(1:20)
n<-c(10,20,13,22,28,12,12,36,19,12,36,75,33,121,37,14,40,16,14,20)
r<-c(.68,.56,.23,.64,.49,-.04,.49,.33,.58,.18,-.11,.27,.26,.40,.49,
 .51,.40,.34,.42,.16)
mod1<-c(1,2,3,4,1,2,8,7,5,3,9,7,5,4,3,2,3,5,7,1)
mod2<-factor(c(rep(c(1,2,3,4),5)))   
data<-data.frame(id,n,r,mod1, mod2)

# Example

MultiModGraph(data, conmod = data$mod1, catmod = data$mod2)
}
\keyword{ aplot }

